==> gnome-panel_3.8.0.orig.tar.xz: gnome-panel-3.8.0/gnome-panel/panel-icon-names.h <==
#ifndef PANEL_ICON_NAMES_H
#define PANEL_ICON_NAMES_H

#define PANEL_ICON_BOOKMARKS		"user-bookmarks"
#define PANEL_ICON_BURNER		"nautilus-cd-burner"
#define PANEL_ICON_COMPUTER		"computer"
#define PANEL_ICON_DESKTOP		"user-desktop"
#define PANEL_ICON_FILESYSTEM		"drive-harddisk"
#define PANEL_ICON_FOLDER		"folder"
#define PANEL_ICON_FOLDER_DOCUMENTS	"folder-documents"
#define PANEL_ICON_FOLDER_DOWNLOAD	"folder-download"
#define PANEL_ICON_FOLDER_MUSIC		"folder-music"
#define PANEL_ICON_FOLDER_PICTURES	"folder-pictures"
#define PANEL_ICON_FOLDER_PUBLIC_SHARE	"folder-publicshare"
#define PANEL_ICON_FOLDER_TEMPLATES	"folder-templates"
#define PANEL_ICON_FOLDER_VIDEOS	"folder-videos"
#define PANEL_ICON_FONTS		"preferences-desktop-font"
#define PANEL_ICON_FORCE_QUIT		"gnome-panel-force-quit"
#define PANEL_ICON_HOME			"user-home"
#define PANEL_ICON_LAUNCHER		"gnome-panel-launcher"
#define PANEL_ICON_LOCKSCREEN		"system-lock-screen"
#define PANEL_ICON_LOGOUT		"system-log-out"
#define PANEL_ICON_MAIN_MENU		"start-here"
#define PANEL_ICON_NETWORK		"network-workgroup"
#define PANEL_ICON_NETWORK_SERVER	"network-server"
#define PANEL_ICON_PANEL		"gnome-panel"
#define PANEL_ICON_RECENT		"document-open-recent"
#define PANEL_ICON_REMOTE		"applications-internet"
#define PANEL_ICON_REMOVABLE_MEDIA	"drive-removable-media"
#define PANEL_ICON_RUN			"system-run"
#define PANEL_ICON_SEPARATOR		"gnome-panel-separator"
#define PANEL_ICON_SAVED_SEARCH		"folder-saved-search"
#define PANEL_ICON_SEARCHTOOL		"system-search"
#define PANEL_ICON_SHUTDOWN		"system-shutdown"
#define PANEL_ICON_THEME		"preferences-desktop-theme"
#define PANEL_ICON_TRASH		"user-trash"
#define PANEL_ICON_UNKNOWN		"image-missing"
#define PANEL_ICON_USER_AVAILABLE	"user-available-symbolic"
#define PANEL_ICON_USER_BUSY		"user-busy-symbolic"
#define PANEL_ICON_USER_IDLE		"user-idle-symbolic"
#define PANEL_ICON_USER_INVISIBLE	"user-invisible-symbolic"

#endif /* PANEL_ICON_NAMES_H */

==> gnome-panel_3.18.2.orig.tar.xz: gnome-panel-3.18.2/gnome-panel/panel-icon-names.h <==
#ifndef PANEL_ICON_NAMES_H
#define PANEL_ICON_NAMES_H

#define PANEL_ICON_BOOKMARKS		"user-bookmarks"
#define PANEL_ICON_BURNER		"nautilus-cd-burner"
#define PANEL_ICON_COMPUTER		"computer"
#define PANEL_ICON_DESKTOP		"user-desktop"
#define PANEL_ICON_FILESYSTEM		"drive-harddisk"
#define PANEL_ICON_FOLDER		"folder"
#define PANEL_ICON_FOLDER_DOCUMENTS	"folder-documents"
#define PANEL_ICON_FOLDER_DOWNLOAD	"folder-download"
#define PANEL_ICON_FOLDER_MUSIC		"folder-music"
#define PANEL_ICON_FOLDER_PICTURES	"folder-pictures"
#define PANEL_ICON_FOLDER_PUBLIC_SHARE	"folder-publicshare"
#define PANEL_ICON_FOLDER_TEMPLATES	"folder-templates"
#define PANEL_ICON_FOLDER_VIDEOS	"folder-videos"
#define PANEL_ICON_FONTS		"preferences-desktop-font"
#define PANEL_ICON_FORCE_QUIT		"gnome-panel-force-quit"
#define PANEL_ICON_HOME			"user-home"
#define PANEL_ICON_HIBERNATE		"gnome-panel-hibernate"
#define PANEL_ICON_LAUNCHER		"gnome-panel-launcher"
#define PANEL_ICON_LOCKSCREEN		"system-lock-screen"
#define PANEL_ICON_LOGOUT		"system-log-out"
#define PANEL_ICON_MAIN_MENU		"start-here"
#define PANEL_ICON_NETWORK		"network-workgroup"
#define PANEL_ICON_NETWORK_SERVER	"network-server"
#define PANEL_ICON_PANEL		"gnome-panel"
#define PANEL_ICON_REBOOT		"view-refresh"
#define PANEL_ICON_RECENT		"document-open-recent"
#define PANEL_ICON_REMOTE		"applications-internet"
#define PANEL_ICON_REMOVABLE_MEDIA	"drive-removable-media"
#define PANEL_ICON_RUN			"system-run"
#define PANEL_ICON_SEPARATOR		"gnome-panel-separator"
#define PANEL_ICON_SAVED_SEARCH		"folder-saved-search"
#define PANEL_ICON_SEARCHTOOL		"system-search"
#define PANEL_ICON_SHUTDOWN		"system-shutdown"
#define PANEL_ICON_SUSPEND		"gnome-panel-suspend"
#define PANEL_ICON_THEME		"preferences-desktop-theme"
#define PANEL_ICON_TRASH		"user-trash"
#define PANEL_ICON_UNKNOWN		"image-missing"
#define PANEL_ICON_USERS		"system-users"

#endif /* PANEL_ICON_NAMES_H */
